@@ -2,6 +2,8 @@ require 'pathname'
 require 'execjs'
 require 'json'
 
+IS_SECTION = /^\s*\[(.+)\]\s*$/
+
 module AutoprefixerRails
   # Ruby to JS wrapper for Autoprefixer processor instance
   class Processor
@@ -37,10 +39,21 @@ module AutoprefixerRails
 
     # Parse Browserslist config
     def parse_config(config)
+      sections = { 'defaults' => [] }
+      current  = 'defaults'
       config.gsub(/#[^\n]*/, '')
             .split(/\n/)
             .map(&:strip)
             .reject(&:empty?)
+            .each do |line|
+              if line =~ IS_SECTION
+                current = line.match(IS_SECTION)[1].strip
+                sections[current] ||= []
+              else
+                sections[current] << line
+              end
+            end
+      sections
     end
 
     private
@@ -56,10 +69,16 @@ module AutoprefixerRails
 
       params = @params
       if not params.has_key?(:browsers) and from
-        config = find_config(from)
-        if config
+        file = find_config(from)
+        if file
+          env    = params[:env].to_s || 'development'
+          config = parse_config(file)
           params = params.dup
-          params[:browsers] = parse_config(config)
+          if config[env]
+            params[:browsers] = config[env]
+          else
+            params[:browsers] = config['defaults']
+          end
         end
       end
 
