@@ -1,22 +1,22 @@
 require 'yaml'
 
 begin
-  require 'sprockets/railtie'
-
   module AutoprefixedRails
     class Railtie < ::Rails::Railtie
       rake_tasks do |app|
         require 'rake/autoprefixer_tasks'
-        Rake::AutoprefixerTasks.new( config(app.root) )
+        Rake::AutoprefixerTasks.new( config(app.root) ) if defined? app.assets
       end
 
-      if config.respond_to?(:assets)
+      if config.respond_to?(:assets) and not config.assets.nil?
         config.assets.configure do |env|
           AutoprefixerRails.install(env, config(env.root))
         end
       else
         initializer :setup_autoprefixer, group: :all do |app|
-          AutoprefixerRails.install(app.assets, config(app.root))
+          if defined? app.assets and not app.assets.nil?
+            AutoprefixerRails.install(app.assets, config(app.root))
+          end
         end
       end
 
@@ -26,6 +26,7 @@ begin
         params = ::YAML.load_file(file) if File.exist?(file)
         params ||= {}
         params = params.symbolize_keys
+        params[:env] ||= Rails.env.to_s
         params
       end
     end
