@@ -1,5 +1,3 @@
-require 'compass/import-once/activate'
-
 http_path       = "/"
 css_dir         = "stylesheets"
 sass_dir        = "sass"
@@ -11,7 +9,10 @@ output_style  = :compressed
 sass_options  = { cache: false }
 line_comments = false
 
-require 'autoprefixer-rails'
+require 'rubygems'
+require 'bundler'
+Bundler.require
+require '../../lib/autoprefixer-rails'
 
 on_stylesheet_saved do |file|
   css = File.read(file)
