@@ -8,9 +8,9 @@ describe CssController, type: :controller do
 
   def test_file(file)
     if Rails.version.split('.').first.to_i >= 5
-      get :test, params: { file: 'sass' }
+      get :test, params: { file: file }
     else
-      get :test, file: 'sass'
+      get :test, file: file
     end
   end
 
@@ -36,8 +36,7 @@ describe CssController, type: :controller do
       expect(response).to be_success
 
       source_map = JSON.parse(response.body)
-      expect(source_map["sources"].first).to(
-        include('spec/app/app/assets/stylesheets/loaded.sass'))
+      expect(source_map["sources"].first).to match(/loaded.*.sass/)
     end
   end
 end
