@@ -8,3 +8,7 @@ require 'rspec/rails'
 RSpec.configure do |c|
   c.filter_run_excluding not_jruby: RUBY_PLATFORM == 'java'
 end
+
+def sprockets_4?
+  Gem::Version.new(Sprockets::VERSION) > Gem::Version.new("4.0.x")
+end
